# -*- coding: utf-8 -*-

# print("Some remarks:")
# print(" * lambda is a reserved work in Python (used in anonymous functions);")
# print(" * O, N, Q, gamma, beta, I, S, C, pi, zeta, E are either reserved by Python or SymPy.")

from .CosW import buildRV as CosW
from .CosW import buildRV as CosineWeibull
from .SecKW import buildRV as SecKW
from .SecKW import buildRV as SecKumaraswamyWeibull
from .SinIW import buildRV as SinIW
from .SinIW import buildRV as SineInverseWeibull
from .TanB import buildRV as TanB
from .TanB import buildRV as TangentBurrXII